package whoop

import (
	"log/slog"
	"os"

	"github.com/knadh/koanf/parsers/dotenv"
	"github.com/knadh/koanf/providers/confmap"
	"github.com/knadh/koanf/providers/env"
	"github.com/knadh/koanf/providers/file"
	"github.com/knadh/koanf/v2"
)

type Config struct {
	WhoopClientID     string `koanf:"WHOOP_CLIENT_ID"`
	WhoopClientSecret string `koanf:"WHOOP_CLIENT_SECRET"`
	WhoopAuthURL      string `koanf:"WHOOP_AUTH_URL"`
	WhoopTokenURL     string `koanf:"WHOOP_TOKEN_URL"`
}

var Conf *Config

var k = koanf.New(".")

var defaultConfigProvider = confmap.Provider(map[string]any{
	"ENV": "local",
	"WHOOP_AUTH_URL": "https://api.prod.whoop.com/oauth/oauth2/auth",
	"WHOOP_TOKEN_URL": "https://api.prod.whoop.com/oauth/oauth2/token",
}, "")

func ProvideConfig() (*Config, error) {
	if Conf == nil {
		err := k.Load(defaultConfigProvider, nil)
		if err != nil {
			slog.Error("error loading default config", "err", err)
			os.Exit(1)
		}

		_ = k.Load(file.Provider(".env"), dotenv.Parser())

		if err := k.Load(env.Provider("", ".", nil), nil); err != nil {
			slog.Error("error loading config", "err", err)
			os.Exit(1)
		}

		Conf = &Config{}
		err = k.Unmarshal("", Conf)
		if err != nil {
			slog.Error("error loading config", "err", err)
			os.Exit(1)
		}
	}

	return Conf, nil
}
